# TODO
# - should mailq and newaliases be in bindir?

# Conditional build:
%bcond_without	pam		# build without PAM support
%bcond_without	table_db	# build table-db backend

Summary:	Free implementation of the server-side SMTP protocol as defined by RFC 5321
Name:		opensmtpd
Version:	5.7.3p2
Release:	3
License:	ISC
Group:		Daemons
Source0:	https://www.opensmtpd.org/archives/%{name}-%{version}.tar.gz
# Source0-md5:	85bdccf1f28945771f79fd33e893cc43
Source1:	%{name}.service
Source2:	%{name}.init
Source3:	%{name}.pam
Source4:	aliases
URL:		http://www.opensmtpd.org/
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	bison
BuildRequires:	db-devel
BuildRequires:	libasr-devel
BuildRequires:	libevent-devel
BuildRequires:	openssl-devel
%{?with_pam:BuildRequires:	pam-devel}
BuildRequires:	rpmbuild(macros) >= 1.228
BuildRequires:	zlib-devel
Requires(post,preun):	/sbin/chkconfig
Requires(postun):	/usr/sbin/groupdel
Requires(postun):	/usr/sbin/userdel
Requires(pre):	/bin/id
Requires(pre):	/usr/bin/getgid
Requires(pre):	/usr/sbin/groupadd
Requires(pre):	/usr/sbin/useradd
Requires:	rc-scripts
Suggests:	ca-certificates
Provides:	group(smtpd)
Provides:	group(smtpq)
Provides:	smtpdaemon
Provides:	user(smtpd)
Provides:	user(smtpq)
Obsoletes:	smtpdaemon
%requires_ge_to	openssl	openssl-devel
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%define		privsepdir	/usr/share/empty
%define		spooldir	/var/spool/smtpd
%define		certsdir	/etc/certs

%description
OpenSMTPD is a FREE implementation of the server-side SMTP protocol as
defined by RFC 5321, with some additional standard extensions. It
allows ordinary machines to exchange e-mails with other systems
speaking the SMTP protocol.

Started out of dissatisfaction with other implementations, OpenSMTPD
nowadays is a fairly complete SMTP implementation. OpenSMTPD is
primarily developed by Gilles Chehade, Eric Faurot and Charles
Longeau; with contributions from various OpenBSD hackers. OpenSMTPD is
part of the OpenBSD Project. The software is freely usable and
re-usable by everyone under an ISC license.

%prep
%setup -q

%build
%{__aclocal}
%{__autoconf}
%{__autoheader}
%{__automake}
%configure \
	--sysconfdir=%{_sysconfdir}/mail \
	--with-ca-file=%{certsdir}/ca-certificates.crt \
	--with-mantype=man \
	%{?with_pam:--with-pam} \
	%{?with_pam:--enable-table-db} \
	--with-privsep-user=smtpd \
	--with-queue-user=smtpq \
	--with-privsep-path=%{privsepdir} \
	--with-sock-dir=%{_localstatedir}/run

%{__make}

%install
rm -rf $RPM_BUILD_ROOT
%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT

install -d $RPM_BUILD_ROOT{%{systemdunitdir},/etc/{rc.d/init.d,pam.d}}
cp -p %{SOURCE1} $RPM_BUILD_ROOT%{systemdunitdir}/opensmtpd.service
install -p %{SOURCE2} $RPM_BUILD_ROOT/etc/rc.d/init.d/opensmtpd
cp -p %{SOURCE4} $RPM_BUILD_ROOT/etc/mail
%if %{with pam}
cp -p %{SOURCE3} $RPM_BUILD_ROOT/etc/pam.d/smtp
%endif
touch $RPM_BUILD_ROOT%{_sysconfdir}/mail/aliases.db

# /usr/sbin/sendmail compatibility is not required /usr/lib/sendmail is
install -d $RPM_BUILD_ROOT%{_prefix}/lib
mv $RPM_BUILD_ROOT{%{_bindir},%{_prefix}/lib}/sendmail

# queue dirs
install -d $RPM_BUILD_ROOT%{spooldir}/{queue,corrupt,incoming,offline,purge,temporary}

%clean
rm -rf $RPM_BUILD_ROOT

%pre
%groupadd -g 297 smtpd
%groupadd -g 298 smtpq
%useradd -u 297 -g smtpd -s /sbin/nologin -c "OpenSMTPd privsep user" -d %{privsepdir} smtpd
%useradd -u 298 -g smtpq -s /sbin/nologin -c "OpenSMTPd queue user" -d %{privsepdir} smtpq

%post
/sbin/chkconfig --add %{name}
%service %{name} restart
%systemd_post %{name}.service

%preun
if [ $1 = 0 ]; then
	%service %{name} stop
	/sbin/chkconfig --del %{name}
fi
%systemd_preun %{name}.service

%postun
if [ "$1" = "0" ]; then
	%userremove smtpd
	%userremove smtpq
	%groupremove smtpd
	%groupremove smtpq
fi
%systemd_reload

%files
%defattr(644,root,root,755)
%doc LICENSE README.md THANKS
%dir %{_sysconfdir}/mail
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/mail/smtpd.conf
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/mail/aliases
%ghost %{_sysconfdir}/mail/aliases.db
%if %{with pam}
%config(noreplace) %verify(not md5 mtime size) /etc/pam.d/smtp
%endif
%attr(754,root,root) /etc/rc.d/init.d/opensmtpd
%{systemdunitdir}/%{name}.service
%attr(755,root,root) %{_sbindir}/mailq
%attr(755,root,root) %{_sbindir}/smtpctl
%attr(755,root,root) %{_sbindir}/smtpd
%attr(755,root,root) %{_prefix}/lib/sendmail
%{_mandir}/man5/aliases.5*
%{_mandir}/man5/forward.5*
%{_mandir}/man5/smtpd.conf.5*
%{_mandir}/man5/table.5*
%{_mandir}/man8/sendmail.8*
%{_mandir}/man8/smtpctl.8*
%{_mandir}/man8/smtpd.8*

%if %{with table_db}
%attr(755,root,root) %{_sbindir}/makemap
%attr(755,root,root) %{_sbindir}/newaliases
%{_mandir}/man8/makemap.8*
%{_mandir}/man8/newaliases.8*
%endif

%dir %{_libdir}/%{name}
%attr(755,root,root) %{_libdir}/%{name}/encrypt
%attr(755,root,root) %{_libdir}/%{name}/mail.local

%dir %attr(711,root,root) %{spooldir}
%dir %attr(1777,root,root) %{spooldir}/offline
%dir %attr(700,smtpq,root) %{spooldir}/corrupt
%dir %attr(700,smtpq,root) %{spooldir}/incoming
%dir %attr(700,smtpq,root) %{spooldir}/purge
%dir %attr(700,smtpq,root) %{spooldir}/queue
%dir %attr(700,smtpq,root) %{spooldir}/temporary
%changelog
* Sun Apr 02 2017 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/opensmtpd.git;a=log;h=master

* Sun Apr 02 2017 Jan Rękorajski <baggins@pld-linux.org> e992884
- rebuild with libevent 2.1.9
- release 3 (by relup.sh)

* Sun Mar 06 2016 Elan Ruusamäe <glen@delfi.ee> 94d27da
- depend on openssl version

* Sun Mar 06 2016 Elan Ruusamäe <glen@delfi.ee> 8b23e85
- add checkconfig support

* Fri Feb 12 2016 Adam Osuchowski <adwol@pld-linux.org> 9af6eac
- up to 5.7.3p2

* Fri Dec 11 2015 Elan Ruusamäe <glen@delfi.ee> ae4734f
- enable table-db

* Fri Dec 11 2015 Elan Ruusamäe <glen@delfi.ee> 9127fec
- up to 5.7.3p1, table-db is not built somewhy

* Tue May 12 2015 Elan Ruusamäe <glen@delfi.ee> b207f9a
- up to 5.4.5p1

* Fri Feb 20 2015 Elan Ruusamäe <glen@delfi.ee> badf784
- fix path to ca file

* Fri Feb 20 2015 Elan Ruusamäe <glen@delfi.ee> 4c4577b
- up to 5.4.4p1, filter and queue binaries not built

* Fri May 16 2014 Elan Ruusamäe <glen@delfi.ee> d6b83af
- seems working; rel 1

* Fri May 16 2014 Elan Ruusamäe <glen@delfi.ee> b350f45
- avoid /usr/lib/opensmtpd/opensmtpd dir

* Fri May 16 2014 Elan Ruusamäe <glen@delfi.ee> bf53c39
- use pidfile for status

* Fri May 16 2014 Elan Ruusamäe <glen@delfi.ee> 2323b70
- package queue dirs

* Fri May 16 2014 Elan Ruusamäe <glen@delfi.ee> 86c67e9
- remove obsolete patches

* Fri May 16 2014 Elan Ruusamäe <glen@delfi.ee> ced5657
- add abuse@, following postfix package

* Fri May 16 2014 Elan Ruusamäe <glen@delfi.ee> 7c1f755
- up to 5.4.2p1

* Sat Nov 02 2013 Elan Ruusamäe <glen@delfi.ee> ad4ea56
- fix service lockfile name

* Sat Nov 02 2013 Elan Ruusamäe <glen@delfi.ee> ddd6674
- ghost aliases.db

* Sat Nov 02 2013 Elan Ruusamäe <glen@delfi.ee> c7bec43
- pass paths to makemap to respect config dir

* Sat Nov 02 2013 Elan Ruusamäe <glen@delfi.ee> 03886c2
- fix chroot path

